;; Generated package description from disk-usage.el  -*- no-byte-compile: t -*-
(define-package "disk-usage" "1.3.3.0.20220815.54920" "Sort and browse disk usage listings" '((emacs "26.1")) :commit "03ce75bbb03a1b5b26c6f91913219ad320919a43" :authors '(("Pierre Neidhardt" . "mail@ambrevar.xyz")) :maintainer '("Pierre Neidhardt" . "mail@ambrevar.xyz") :keywords '("files" "convenience" "tools") :url "https://gitlab.com/Ambrevar/emacs-disk-usage")
